@@ -3,7 +3,7 @@ import pandas as pd
 import pymssql
 import cx_Oracle as cx
 
-from .queries import *
+# from .queries import *
 from pandas import read_sql_query
 
 cx.init_oracle_client(lib_dir= r'C:/Program Files/Oracle/instantclient_21_3')
